@@ -45,7 +45,7 @@ bl_lin_matrix <- function(blg, Xfun, args) {
         if (is.null(args$lambda)) {
 
             ### <FIXME>: is there a better way to feed XtX into lambdadf?
-            lambdadf <- df2lambda(matrix(0, ncol = ncol(X$X1) + ncol(X$X2)), 
+            lambdadf <- df2lambda(matrix(0, ncol = ncol(X$X1) + ncol(X$X2)),
                                   df = args$df, lambda = args$lambda,
                                   dmat = K, weights = weights, XtX = XtX)
             ### </FIXME>
@@ -73,9 +73,8 @@ bl_lin_matrix <- function(blg, Xfun, args) {
             mysolve <- function(y) {
                 Y <- matrix(y, nrow = n1) * W
                 XWY <- crossprod(X$X1, Y) %*% X$X2
-                .Call("La_dgesv", XtX, matrix(as(XWY, "matrix"), ncol = 1), 
-                      .Machine$double.eps,
-                      PACKAGE = "base")
+                solve(XtX, matrix(as(XWY, "matrix"), ncol = 1),
+                      LINPACK = FALSE)
             }
         }
 
@@ -117,7 +116,7 @@ bl_lin_matrix <- function(blg, Xfun, args) {
                 newdata <- newdata[nm]
                 X <- newX(newdata)$X
             }
-            ncfprod <- function(b) 
+            ncfprod <- function(b)
                 as.vector(as(tcrossprod(X$X1 %*% b, X$X2), "matrix"))
             aggregate <- match.arg(aggregate)
             pr <- switch(aggregate, "sum" = {
@@ -136,7 +135,7 @@ bl_lin_matrix <- function(blg, Xfun, args) {
             },
             "none" = {
                 ret <- c()
-                for (b in cf) {   
+                for (b in cf) {
                     ret <- cbind(ret, ncfprod(b))
                 }
                 ret
